#!/usr/bin/python3
# -*- coding: utf8 -*-
#
# @author: natloc_developer
# @date: 2019/12/29
# @time: 21:42
# @doc: 美餐通知
# Copyright © 2019 natloc_developer. All rights reserved.
#


from thd.calendar.ics import ICS_XiaoBangGuiHua
import nat.datetime

if ICS_XiaoBangGuiHua().reqIcal().isEventDay():
	import thd.wechat.group_robot
	
	__WEB_HOOK = "https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=eabcee36-cfc3-4661-b027-9de1e5f9de58"
	#__WEB_HOOK = "https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=49e78e2a-02a6-4f60-8949-45c026174d21" # 测试
	__LOGIN_URL = "meican://home"
	__LOGO_URL = "https://www.meican.com/favicon.ico"


	newsMsg = thd.wechat.group_robot.NewsMessage(__WEB_HOOK)
	newsMsg.appendNews(u"美餐下单提示", "", __LOGIN_URL, "")
	#newsMsg.send()

	txtMsg = thd.wechat.group_robot.TextMessage(__WEB_HOOK)
	txtMsg.setContent(u"%s，你点了没？" %(u"午餐" if nat.datetime.now().hour <= 12 else u"晚餐"))
	txtMsg.setMentionedAll()
	txtMsg.send()



#!/usr/local/bin/python3
# -*- coding: utf8 -*-
#
# @author: natloc_developer
# @date: 2020/1/6
# @time: 18:17
# @doc:
# Copyright © 2020 natloc_developer. All rights reserved.
#

import argparse


# 实例化对象
def createParser():
    return argparse.ArgumentParser()

# 生成参数对象
def genArgs(parser):
    if None != parser:
        return parser.parse_args()
    else:
        return None



# MARK:- 组

# 创建分组信息
def createGroup(parser, required = False):
    if None != parser:
        return parser.add_mutually_exclusive_group(required = required)
    else:
        return None





#!/usr/local/bin/python3
# -*- coding: utf8 -*-
#
# @author: natloc_developer
# @date: 2020/1/2
# @time: 17:14
# @doc:
# Copyright © 2020 natloc_developer. All rights reserved.
#
# 研发面板：
#   11：-> START PROGRESS
#   31：-> TODO
#   71：-> START TEST
# BUG:
#   5：-> RESOVLED
#   3: -> REOPENED
#

from bs4 import BeautifulSoup

import nat.cmd
import nat.log
import nat.datetime
import nat.string


__ACCOUNT_USER = "luxiaolong"
__ACCOUNT_PASSWD = "654321qwerQ"


# 根据 issue code 获取标题
# return (Title :: string, Type :: string)
def reqJiraTitle(code):
    jiraUrl = u"http://jira.xiaobangtouzi.com/browse/FQ-%i" %(code)

    cmdStr = u"curl -u %s:%s %s" %(__ACCOUNT_USER, __ACCOUNT_PASSWD, jiraUrl)
    html = nat.cmd.executeRead(cmdStr).read()
    htmlBs = BeautifulSoup(html, "html.parser")
    titleNode = htmlBs.select_one("#summary-val")

    if None != titleNode:
        # 自动完成 issue
        issueId = htmlBs.select_one("#key-val").get("rel", [""])[0]
        
        cookieDict = __reqJiraRespSetCookieDict(code)
        atlToken = cookieDict.get("atlassian.xsrf.token", "")
        jsessionId = cookieDict.get("jsessionid", "")

        if "" != issueId and "" != atlToken and "" != jsessionId:
            status = __getIssueStatus(htmlBs)
            __finishIssue(issueId, code, jsessionId, atlToken, status, __getIssueAssignee(htmlBs))

        return (titleNode.get_text(), __getIssueTypeName(status))
    else:
        return (u"FQ-%i" %(code), "unknown")

# 请求 issue 响应的 Set-Cookie 的值字典
# return {}
def __reqJiraRespSetCookieDict(code):
    jiraUrl = u"http://jira.xiaobangtouzi.com/browse/FQ-%i" % (code)

    cmdStr = u"curl -u %s:%s %s -I" % (__ACCOUNT_USER, __ACCOUNT_PASSWD, jiraUrl)

    cookieDict = {}
    for cookie in nat.cmd.executeRead(cmdStr).readlines():
        splitArr = cookie.split(":")
        if 2 == len(splitArr) and "set-cookie" == splitArr[0].strip().lower():
            splitArr = splitArr[1].split(";")
            if len(splitArr) > 0:
                splitArr = splitArr[0].split("=")
                if 2 == len(splitArr):
                    key = splitArr[0].strip().lower()
                    value = splitArr[1].strip()
                    cookieDict[key] = value

    return cookieDict

# 获取 issue 的状态
# return: string   # 如："open" | "reopened" | "resolved" | "to do" | "in progress" | "in test" | "done"
def __getIssueStatus(htmlBeautifulSoup):
    for li in htmlBeautifulSoup.select_one("#issuedetails").find_all("li"):
        if "status:" == li.strong.get_text().lower():
            return li.select_one("#status-val").span.get_text().lower()

    return ""

# 获取经办人拼音
# return string
def __getIssueAssignee(htmlBeautifulSoup):
    for dl in htmlBeautifulSoup.select_one("#peopledetails").find_all("dl"):
        if "assignee:" == dl.dt.get_text().lower():
            return dl.dd.select_one("#assignee-val").span.get("rel")

    return ""

# 获取 issue 的类型名；暂时只区分 任务 和 bug 类型
# return string   # 小写；如："mission" | "bug" | "unknown"
def __getIssueTypeName(status):
    status = status.lower()
    if "to do" == status or "in progress" == status or "in test" == status:
        return "mission"
    elif "open" == status or "reopened" == status or "resolved" == status:
        return "bug"
    else:
        return "unknown"

# 改变经办人
# return bool
def __changeAssignee(issueId, code, assignee, jsessionId, atlToken):
    if __ACCOUNT_USER.lower() == assignee.lower():
        return True

    else:
        jiraUrl = u"http://jira.xiaobangtouzi.com/secure/AjaxIssueAction.jspa"
        formKvs = u"assignee=%s&issueId=%s&atl_token=%s" %(assignee, issueId, atlToken)

        cmdStr = u"curl -u %s:%s \"%s\" -b \"JSESSIONID=%s; atlassian.xsrf.token=%s\" -X POST -d '%s'" % (
        __ACCOUNT_USER, __ACCOUNT_PASSWD, jiraUrl, jsessionId, atlToken, formKvs)

        htmlRet = nat.cmd.executeRead(cmdStr)
        return True

# 完成 issue
# return: bool
def __finishIssue(issueId, code, jsessionId, atlToken, status, assignee):
    if "to do" == status:
        action = 11
    elif "in progress" == status:
        action = 71
    elif "open" == status or "reopened" == status:
        action = 5
    elif "resolved" == status or "in test" == status:
        return True
    else:
        nat.log.error(u"完成 jira issue 出错，当前状态不正确。issure 编号：%i, 状态: %s" %(code, status))
        return False

    jiraUrl = u"http://jira.xiaobangtouzi.com/secure/WorkflowUIDispatcher.jspa?id=%s&atl_token=%s&action=%i" %(issueId, atlToken, action)

    cmdStr = u"curl -u %s:%s \"%s\" -b \"JSESSIONID=%s; atlassian.xsrf.token=%s\"" %(__ACCOUNT_USER, __ACCOUNT_PASSWD, jiraUrl, jsessionId, atlToken)
    htmlRet = nat.cmd.executeRead(cmdStr).read()
    isSuccess = "" == nat.string.trim(htmlRet)

    # 需额外完成一步：进行中 -> 已提测
    if isSuccess and "to do" == status:
        __finishIssue(issueId, code, jsessionId, atlToken, "in progress", assignee)

    elif isSuccess and __changeAssignee(issueId, code, assignee, jsessionId, atlToken):
        return True

    else:
        nat.log.error(u"完成 issue 失败，issue 单号：%i" %(code))



# 输出耗时
def printArchiveDuration(startTi):
    __costSeconds = int(nat.datetime.getTi() - startTi)
    __costMinutes = __costSeconds / 60
    __costSeconds = __costSeconds % 60
    nat.log.warn(u"完成打包任务，共耗时：%i 分 %i 秒" % (__costMinutes, __costSeconds))


# 同步数据到 QA 集成平台
def syncQualityQA(appName, version, code, branchName, platform, commitId, mode, submitter, downloadUrl):
    __QUALITY_QA_URL = "https://quality-qa.xiaobangtouzi.com/treasure/api/v1/create"
    __QUALITY_QA_HEADER = "Content-Type:application/json"
    __QUALITY_QA_DATA = """{"name": "%s","version_name": "%s", "version": "%s", "branch": "%s", "platform": "%s", "commit_id": "%s", "type": "%s", "submitter": "%s", "created": "%s", "url": "%s"}"""

    quality_qa_data = __QUALITY_QA_DATA %(appName, version, code, branchName, platform, commitId, mode, submitter, nat.datetime.now(), downloadUrl)
    quality_qa_requrest = "curl '%s' -H '%s' -d '%s'" % (__QUALITY_QA_URL, __QUALITY_QA_HEADER, quality_qa_data)

    nat.cmd.execute(quality_qa_requrest)

# 创建 issue 行信息
def __mkJiraIssueLine(contentLine):
    jiraCode = int(contentLine)
    (jiraIssueTitle, jiraIssueType) = reqJiraTitle(jiraCode)
    mdColor = "info" if "mission" == jiraIssueType else "warning"
    issueTag = "任务" if "mission" == jiraIssueType else "bug"
    return u"- **<font color=\"%s\">[%s]</font>** [%s](http://jira.xiaobangtouzi.com/browse/FQ-%i)\n" % (mdColor, issueTag, jiraIssueTitle, jiraCode)


# 补充完善更新日志行信息
# return string
def fillReleaseNotes(contentLineArr):
    content = u""

    for contentLine in contentLineArr:
        contentLine = contentLine.strip()

        if "" == contentLine:
            continue

        # info 类别：任务
        elif contentLine.startswith("+"):
            contentLine = contentLine[1:].strip()
            try:
                content += __mkJiraIssueLine(contentLine)
            except:
                contentLine = contentLine[1:].strip()
                content += u"- **<font color=\"info\">[任务]</font>** %s\n" %(contentLine)

        # warning 类别：bug
        elif contentLine.startswith("-"):
            contentLine = contentLine[1:].strip()
            try:
                content += __mkJiraIssueLine(contentLine)
            except:
                nat.log.exit(u"- 类别必须填写 jira 的单号数字，当前内容错误：%s" %(contentLine))

        # comment 类别：
        elif contentLine.startswith("*"):
            contentLine = contentLine[1:].strip()
            content += u"- **<font color=\"comment\">[备注]</font>** %s\n" %(contentLine)

        # 引用 类别：
        elif contentLine.startswith(">"):
            content += u"%s\n" %(contentLine)

        else:
            content += u"- %s\n" %(contentLine)

    return content


#!/usr/local/bin/python3
# -*- coding: utf8 -*-
#
# @author: natloc
# @date: 2019/10/22
# @time: 12:59
# @doc: 财商 * h5 脚本
# Copyright © 2019 natloc. All rights reserved.
#

import utils

# --- 必选项

APP_NAME = u"小帮规划"


#QIYE_WECHAT_WEBHOOK = "https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=309f173d-de7a-4f0a-ba3a-05f01ca7ea8a"  # 财商: 正式
QIYE_WECHAT_WEBHOOK = "https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=49e78e2a-02a6-4f60-8949-45c026174d21"  # 测试：一个人的群

MODE_URL_DICT = {
    "qa": "https://app-qa.xiaobangguihua.com/course",
    "staging": "https://app-staging.xiaobangguihua.com/course",
    "production": "https://app.xiaobangguihua.com/course"
}



import nat.cmdOpt
import nat.string
import thd.wechat.group_robot
import nat.log

__parser = nat.cmdOpt.createParser()
__parser.add_argument("--releaseNote", help=u"更新日志", type=str, required=True)
__parser.add_argument("--mode", help=u"模式：qa | staging | production", type=str, required=True)
__args = nat.cmdOpt.genArgs(__parser)

# --- 更新日志内容
__releaseNoteStr = nat.string.trim(__args.releaseNote)
__releaseNote = utils.fillReleaseNotes(__releaseNoteStr.split("\n"))

# --- 模式
__mode = nat.string.trim(__args.mode)
__modeUrl = MODE_URL_DICT.get(__mode, "")
if "" == __modeUrl:
    __mode = "qa"
    __modeUrl = MODE_URL_DICT[__mode]

# --- 发送到微信群
msgMd = thd.wechat.group_robot.MarkdownMessage(QIYE_WECHAT_WEBHOOK)
__modeName = __mode.upper() if "qa" == __mode else __mode.capitalize()
msgMd.append("【提测-H5-%s】" %(__modeName), fragmentCount=3, shouldAppendNewLine=True)
msgMd.append(__releaseNote)
msgMd.append(u"\n👉 %s" %(msgMd.mkLink(u"提测链接", __modeUrl)))
msgMd.send()

msgText = thd.wechat.group_robot.TextMessage(QIYE_WECHAT_WEBHOOK)
msgText.setMentionedAll()
msgText.send()

# --- 完成
nat.log.warn("H5 提测完成")


#!/usr/bin/python
# -*- coding: utf8 -*-
#
# @author: natloc_developer
# @date: 2019/12/29
# @time: 21:32
# @doc: 通知更新迭代信息
# Copyright © 2019 natloc_developer. All rights reserved.
#
#
# 更新日期：
#   迭代第2周的周五

from thd.calendar.ics import ICS_XiaoBangGuiHua

if ICS_XiaoBangGuiHua().reqIcal().isEventLastDay():
	import thd.wechat.group_robot

	__WEB_HOOK = "https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=309f173d-de7a-4f0a-ba3a-05f01ca7ea8a"  # 财商: 正式
	# __WEB_HOOK = "https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=49e78e2a-02a6-4f60-8949-45c026174d21" # 测试

	robot = thd.wechat.group_robot.TextMessage(__WEB_HOOK)
	robot.setContent("请将本迭代的更新内容、截图到迭代文档的评论区")
	robot.appendMentionedUser("lijing")
	robot.send()
